@@ -27,36 +27,45 @@ from sentry.utils.safe import safe_execute
 from sentry.utils.http import absolute_uri
 from django.core.urlresolvers import reverse
 
-def validate_urls(value, **kwargs):
-    output = []
-    for url in value.split('\n'):
-        url = url.strip()
-        if not url:
-            continue
-        if not url.startswith(('http://', 'https://')):
-            raise PluginError('Not a valid URL.')
-        if not is_valid_url(url):
-            raise PluginError('Not a valid URL.')
-        output.append(url)
-    return '\n'.join(output)
+import sentry_dingtalk_bot
+
+
+
+# def validate_urls(value, **kwargs):
+#     output = []
+#     for url in value.split('\n'):
+#         url = url.strip()
+#         if not url:
+#             continue
+#         if not url.startswith(('http://', 'https://')):
+#             raise PluginError('Not a valid URL.')
+#         if not is_valid_url(url):
+#             raise PluginError('Not a valid URL.')
+#         output.append(url)
+#     return '\n'.join(output)
 
 
 class DingtalkForm(notify.NotificationConfigurationForm):
-    urls = forms.CharField(
+    webhookUrl = forms.CharField(
         label=_('Dingtalk robot url'),
         widget=forms.Textarea(attrs={
             'class': 'span6', 'placeholder': 'https://oapi.dingtalk.com/robot/send?access_token=9bacf9b193f'}),
         help_text=_('Enter dingtalk robot url.'))
 
-    def clean_url(self):
-        value = self.cleaned_data.get('url')
-        return validate_urls(value)
+    custom_keyword = forms.CharField(
+        label=_('Custom Keyword'),
+        widget=forms.CharField(attrs={'placeholder': 'keywords'}),
+        help_text=_('Enter custom keyword.'))
+
+    # def clean_url(self):
+    #     value = self.cleaned_data.get('url')
+    #     return validate_urls(value)
 
  
 class DingtalkPlugin(notify.NotificationPlugin):
     author = 'lpcoder'
     author_url = 'https://github.com/liupcoder/sentry_dingtalk_bot'
-    version = sentry.VERSION
+    version = sentry_dingtalk_bot.VERSION
     description = "Integrates dingtalk robot."
     resource_links = [
         ('Bug Tracker', 'https://github.com/liupcoder/sentry_dingtalk_bot/issues'),
@@ -73,11 +82,11 @@ class DingtalkPlugin(notify.NotificationPlugin):
     logger = logging.getLogger('sentry.plugins.dingtalk')
 
     def is_configured(self, project, **kwargs):
-        return bool(self.get_option('urls', project))
+        return bool(self.get_option('webhookUrl', project))
 
     def get_config(self, project, **kwargs):
         return [{
-            'name': 'urls',
+            'name': 'webhookUrl',
             'label': 'dingtalk robot url',
             'type': 'textarea',
             'help': 'Enter dingtalk robot url.',
@@ -87,18 +96,18 @@ class DingtalkPlugin(notify.NotificationPlugin):
         }] 
 
     def get_webhook_urls(self, project):
-        url = self.get_option('urls', project)
+        url = self.get_option('webhookUrl', project)
         if not url:
             return ''
         return url 
 
-    def send_webhook(self, url, payload):
-        return safe_urlopen(
-            url=url,
-            json=payload,
-            timeout=self.timeout,
-            verify_ssl=False,
-        )
+    # def send_webhook(self, url, payload):
+    #     return safe_urlopen(
+    #         url=url,
+    #         json=payload,
+    #         timeout=self.timeout,
+    #         verify_ssl=False,
+    #     )
 
     def get_group_url(self, group):
         '''
